"use client";
import Image from "next/image";
import React, { Fragment, useState } from "react";
import Link from "next/link";
import MenuButton from "../ProfileDropDown/MenuButton";
import { Dialog, Transition } from "@headlessui/react";
import ProfileDropDown from "../ProfileDropDown/ProfileDropDown";

const Header = () => {
  const [isOpen, setIsOpen] = useState(false);
  return (
    <header className="bg-white !p-2 sm:!p-3 theme-container flex justify-between items-center sm:gap-4">
      <Link href="/">
        <figure className="flex gap-3 items-center">
          <Image
            className="h-[75px] w-[50px] sm:w-[78px]"
            src="/assets/images/logo.svg"
            height={75}
            width={78}
            alt="Logo"
          />
          <h1 className="hidden sm:block lg:text-2xl text-lg text-dark-blue font-medium">
            Funds Verifier
          </h1>
        </figure>
      </Link>
      <nav>
        <ul className="hidden xl:flex gap-6 items-start">
          <Link href="/">
            <li className="xl:text-lg border-b border-prussianBlue text-prussianBlue cursor-pointer font-medium">
              Home
            </li>
          </Link>
          <li className="xl:text-lg cursor-pointer">How it works</li>
          <li className="xl:text-lg cursor-pointer">Categories</li>
          <li className="xl:text-lg cursor-pointer">News And Trends</li>
          <li className="xl:text-lg cursor-pointer">
            Auctions
            <span className="block text-reefGold text-sm font-medium">
              [Coming Soon]
            </span>
          </li>
        </ul>
      </nav>
      <div className="flex items-center gap-2 sm:gap-6">
        <ProfileDropDown />
        <div>
          <div className="block xl:hidden">
            <MenuButton open={isOpen} setOpen={setIsOpen} />
            <Transition show={isOpen} as={Fragment}>
              <Dialog
                unmount={false}
                onClose={() => setIsOpen(false)}
                className="fixed z-50 inset-0"
              >
                <div className="flex w-full h-screen">
                  <Transition.Child
                    as={Fragment}
                    enterFrom="blur-none"
                    enterTo="blur-sm"
                    entered="blur-sm"
                    leaveFrom="blur-sm"
                    leaveTo="blur-none"
                  >
                    <Dialog.Overlay className="z-40 fixed inset-0 backdrop-blur-sm" />
                  </Transition.Child>
                  <Transition.Child
                    as={Fragment}
                    enter="transition ease-in-out duration-500 transform"
                    enterFrom="translate-y-full"
                    enterTo="translate-y-0"
                    leave="transition ease-in-out duration-500 transform"
                    leaveFrom="translate-y-0"
                    leaveTo="translate-y-full"
                  >
                    <nav
                      className={`z-40  bg-white border-t-2 border-gray-200 w-full p-5 text-left align-middle shadow-xl absolute bottom-0 h-auto`}
                    >
                      <ul className="gap-3 flex flex-col justify-center items-center">
                        <li className="text-lg border-b border-prussianBlue text-prussianBlue cursor-pointer font-medium">
                          Home
                        </li>
                        <li className="text-lg cursor-pointer">How it works</li>
                        <li className="text-lg cursor-pointer">Categories</li>
                        <li className="text-lg cursor-pointer">
                          News And Trends
                        </li>
                        <li className="text-lg cursor-pointer">
                          Auctions
                          <span className="block text-reefGold text-sm font-medium">
                            [Coming Soon]
                          </span>
                        </li>
                      </ul>
                    </nav>
                  </Transition.Child>
                </div>
              </Dialog>
            </Transition>
          </div>
        </div>
      </div>
    </header>
  );
};
export default Header;
